@@ -76,7 +76,7 @@ def get_user_storage_provider(request, owner_username=None, storage_resource_id=
 
 def get_default_storage_resource_id(request):
     backend = get_user_storage_provider(request)
-    return backend.storage_resource_id
+    return backend.resource_id
 
 
 def save(request, path, file, name=None, content_type=None, storage_resource_id=None, experiment_id=None):
